@@ -4,6 +4,8 @@
 # @Author : yangpingyan@gmail.com
 from .chrome_api import *
 from .thread_api import *
+from .file_api import *
+from .image_api import *
 
-__VERSION__ = '0.0.24'
+__VERSION__ = '0.0.25'
 print(f"ypyapi version is: {__VERSION__}")
